import { IBigNumber, IBigNumberRoundingModeName, IBigNumberFormat, IType, IConfig, IBigNumberToType } from '../shared/types.js';
/**
 * Builds the error message that will be thrown in case the provided value cannot be instantiated.
 * The encoding of the error is managed safely as there are values in JavaScript that cannot be
 * stringified, such as Symbol(value).
 * @param value
 * @param error?
 * @returns string
 */
declare const buildInvalidValueErrorMessage: (value: any, error?: any) => string;
/**
 * Builds the configuration that will be used to process a value.
 * @param config
 * @returns IConfig
 * @throws
 * - INVALID_DECIMAL_PLACES: if an invalid number of decimal places are provided
 */
declare const buildConfig: (config?: Partial<IConfig>) => IConfig;
/**
 * Rounds a BigNumber Instance to a given precision by making use of a custom rounding mode.
 * @param value
 * @param decimalPlaces
 * @param roundingMode
 * @returns IBigNumber
 * @throws
 * - INVALID_ROUNDING_MODE: if the rounding mode name is not supported
 */
declare const roundBigNumber: (value: IBigNumber, decimalPlaces: number, roundingMode: IBigNumberRoundingModeName) => IBigNumber;
/**
 * Converts a BigNumber Instance into a custom type.
 * @param value
 * @param type
 * @returns IBigNumberToType<T>
 * @throws
 * - INVALID_TYPE: if the processing type is not supported
 */
declare const convertBigNumberToType: <T extends IType>(value: IBigNumber, type: T) => IBigNumberToType<T>;
/**
 * Builds the configuration object used to prettify a value.
 * @param config?
 * @returns IBigNumberFormat
 */
declare const buildFormatConfig: (config?: Partial<IBigNumberFormat>) => IBigNumberFormat;
/**
 * Sorting function used to order a BigNumber Array in any direction.
 * @param direction
 * @returns (a: IBigNumber, b: IBigNumber): number
 */
declare const sortBigNumbers: (direction: 'asc' | 'desc') => (a: IBigNumber, b: IBigNumber) => number;
export { buildInvalidValueErrorMessage, buildConfig, roundBigNumber, convertBigNumberToType, buildFormatConfig, sortBigNumbers, };
